@@ -81,9 +81,10 @@
Source code for antropy.fractal
"""Fractal functions"""
+from math import floor, log
+
import numpy as np
from numba import jit, types
-from math import log, floor
from .entropy import num_zerocross
from .utils import _linear_regression, _log_n
@@ -558,7 +559,7 @@ Source code for antropy.fractal
© Copyright 2018-2024, Raphael Vallat.
- Created using Sphinx 7.4.7.
+ Created using Sphinx 8.1.3.
diff --git a/docs/build/html/_modules/index.html b/docs/build/html/_modules/index.html
index c611a36..0cc0b09 100644
--- a/docs/build/html/_modules/index.html
+++ b/docs/build/html/_modules/index.html
@@ -4,16 +4,16 @@
- Overview: module code — antropy 0.1.7 documentation
+ Overview: module code — antropy 0.1.8 documentation
-
-
+
+
-
+
@@ -39,7 +39,7 @@
antropy
- 0.1.7
+ 0.1.8
@@ -98,7 +98,7 @@
All modules for which code is available
© Copyright 2018-2024, Raphael Vallat.
- Created using Sphinx 7.4.7.
+ Created using Sphinx 8.1.3.
diff --git a/docs/build/html/_sources/changelog.rst.txt b/docs/build/html/_sources/changelog.rst.txt
index 05504c8..1efbe43 100644
--- a/docs/build/html/_sources/changelog.rst.txt
+++ b/docs/build/html/_sources/changelog.rst.txt
@@ -3,6 +3,11 @@
What's new
##########
+v0.1.8 (December 2024)
+----------------------
+
+- Switch to modern python packaging
+- Use ruff instead of black/flake8
v0.1.7 (December 2024)
----------------------
diff --git a/docs/build/html/_sources/index.rst.txt b/docs/build/html/_sources/index.rst.txt
index dbddd32..f2e1895 100644
--- a/docs/build/html/_sources/index.rst.txt
+++ b/docs/build/html/_sources/index.rst.txt
@@ -36,6 +36,15 @@ or conda
conda config --set channel_priority strict
conda install antropy
+To build and install from source, clone this repository or download the source archive and decompress the files
+
+.. code-block:: shell
+
+ cd antropy
+ pip install ".[test]" # install the package
+ pip install -e ".[test]" # or editable install
+ pytest
+
**Dependencies**
- `numpy
`_
diff --git a/docs/build/html/_static/basic.css b/docs/build/html/_static/basic.css
index f316efc..7ebbd6d 100644
--- a/docs/build/html/_static/basic.css
+++ b/docs/build/html/_static/basic.css
@@ -1,12 +1,5 @@
/*
- * basic.css
- * ~~~~~~~~~
- *
* Sphinx stylesheet -- basic theme.
- *
- * :copyright: Copyright 2007-2024 by the Sphinx team, see AUTHORS.
- * :license: BSD, see LICENSE for details.
- *
*/
/* -- main layout ----------------------------------------------------------- */
@@ -115,15 +108,11 @@ img {
/* -- search page ----------------------------------------------------------- */
ul.search {
- margin: 10px 0 0 20px;
- padding: 0;
+ margin-top: 10px;
}
ul.search li {
- padding: 5px 0 5px 20px;
- background-image: url(file.png);
- background-repeat: no-repeat;
- background-position: 0 7px;
+ padding: 5px 0;
}
ul.search li a {
diff --git a/docs/build/html/_static/copybutton.js b/docs/build/html/_static/copybutton.js
index f695d9f..ff4aa32 100644
--- a/docs/build/html/_static/copybutton.js
+++ b/docs/build/html/_static/copybutton.js
@@ -20,7 +20,7 @@ const messages = {
},
'fr' : {
'copy': 'Copier',
- 'copy_to_clipboard': 'Copié dans le presse-papier',
+ 'copy_to_clipboard': 'Copier dans le presse-papier',
'copy_success': 'Copié !',
'copy_failure': 'Échec de la copie',
},
@@ -224,7 +224,7 @@ var copyTargetText = (trigger) => {
var target = document.querySelector(trigger.attributes['data-clipboard-target'].value);
// get filtered text
- let exclude = '.linenos, .gp';
+ let exclude = '.linenos';
let text = filterText(target, exclude);
return formatCopyText(text, '>>> |\\.\\.\\. |\\$ ', true, true, true, true, '', '')
diff --git a/docs/build/html/_static/doctools.js b/docs/build/html/_static/doctools.js
index 4d67807..0398ebb 100644
--- a/docs/build/html/_static/doctools.js
+++ b/docs/build/html/_static/doctools.js
@@ -1,12 +1,5 @@
/*
- * doctools.js
- * ~~~~~~~~~~~
- *
* Base JavaScript utilities for all Sphinx HTML documentation.
- *
- * :copyright: Copyright 2007-2024 by the Sphinx team, see AUTHORS.
- * :license: BSD, see LICENSE for details.
- *
*/
"use strict";
diff --git a/docs/build/html/_static/documentation_options.js b/docs/build/html/_static/documentation_options.js
index 8d5909e..4099efb 100644
--- a/docs/build/html/_static/documentation_options.js
+++ b/docs/build/html/_static/documentation_options.js
@@ -1,5 +1,5 @@
const DOCUMENTATION_OPTIONS = {
- VERSION: '0.1.7',
+ VERSION: '0.1.8',
LANGUAGE: 'en',
COLLAPSE_INDEX: false,
BUILDER: 'html',
diff --git a/docs/build/html/_static/language_data.js b/docs/build/html/_static/language_data.js
index 367b8ed..c7fe6c6 100644
--- a/docs/build/html/_static/language_data.js
+++ b/docs/build/html/_static/language_data.js
@@ -1,13 +1,6 @@
/*
- * language_data.js
- * ~~~~~~~~~~~~~~~~
- *
* This script contains the language-specific data used by searchtools.js,
* namely the list of stopwords, stemmer, scorer and splitter.
- *
- * :copyright: Copyright 2007-2024 by the Sphinx team, see AUTHORS.
- * :license: BSD, see LICENSE for details.
- *
*/
var stopwords = ["a", "and", "are", "as", "at", "be", "but", "by", "for", "if", "in", "into", "is", "it", "near", "no", "not", "of", "on", "or", "such", "that", "the", "their", "then", "there", "these", "they", "this", "to", "was", "will", "with"];
diff --git a/docs/build/html/api.html b/docs/build/html/api.html
index 09f0faf..2251806 100644
--- a/docs/build/html/api.html
+++ b/docs/build/html/api.html
@@ -5,16 +5,16 @@
-
API reference — antropy 0.1.7 documentation
+
API reference — antropy 0.1.8 documentation
-
-
+
+
-
+
@@ -41,7 +41,7 @@
antropy
-
0.1.7
+
0.1.8
diff --git a/docs/build/html/changelog.html b/docs/build/html/changelog.html
index 98e43a2..128feb7 100644
--- a/docs/build/html/changelog.html
+++ b/docs/build/html/changelog.html
@@ -5,16 +5,16 @@
diff --git a/docs/build/html/_static/searchtools.js b/docs/build/html/_static/searchtools.js
index b08d58c..2c774d1 100644
--- a/docs/build/html/_static/searchtools.js
+++ b/docs/build/html/_static/searchtools.js
@@ -1,12 +1,5 @@
/*
- * searchtools.js
- * ~~~~~~~~~~~~~~~~
- *
* Sphinx JavaScript utilities for the full-text search.
- *
- * :copyright: Copyright 2007-2024 by the Sphinx team, see AUTHORS.
- * :license: BSD, see LICENSE for details.
- *
*/
"use strict";
@@ -20,7 +13,7 @@ if (typeof Scorer === "undefined") {
// and returns the new score.
/*
score: result => {
- const [docname, title, anchor, descr, score, filename] = result
+ const [docname, title, anchor, descr, score, filename, kind] = result
return score
},
*/
@@ -47,6 +40,14 @@ if (typeof Scorer === "undefined") {
};
}
+// Global search result kind enum, used by themes to style search results.
+class SearchResultKind {
+ static get index() { return "index"; }
+ static get object() { return "object"; }
+ static get text() { return "text"; }
+ static get title() { return "title"; }
+}
+
const _removeChildren = (element) => {
while (element && element.lastChild) element.removeChild(element.lastChild);
};
@@ -64,9 +65,13 @@ const _displayItem = (item, searchTerms, highlightTerms) => {
const showSearchSummary = DOCUMENTATION_OPTIONS.SHOW_SEARCH_SUMMARY;
const contentRoot = document.documentElement.dataset.content_root;
- const [docName, title, anchor, descr, score, _filename] = item;
+ const [docName, title, anchor, descr, score, _filename, kind] = item;
let listItem = document.createElement("li");
+ // Add a class representing the item's type:
+ // can be used by a theme's CSS selector for styling
+ // See SearchResultKind for the class names.
+ listItem.classList.add(`kind-${kind}`);
let requestUrl;
let linkUrl;
if (docBuilder === "dirhtml") {
@@ -115,8 +120,10 @@ const _finishSearch = (resultCount) => {
"Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories."
);
else
- Search.status.innerText = _(
- "Search finished, found ${resultCount} page(s) matching the search query."
+ Search.status.innerText = Documentation.ngettext(
+ "Search finished, found one page matching the search query.",
+ "Search finished, found ${resultCount} pages matching the search query.",
+ resultCount,
).replace('${resultCount}', resultCount);
};
const _displayNextItem = (
@@ -138,7 +145,7 @@ const _displayNextItem = (
else _finishSearch(resultCount);
};
// Helper function used by query() to order search results.
// Each input is an array of [docname, title, anchor, descr, score, filename].
// Order the results by score (in opposite order of appearance, since the
// `_displayNextItem` function uses pop() to retrieve items) and then alphabetically.
const _orderResultsByScoreThenName = (a, b) => {
@@ -248,6 +255,7 @@ const Search = {
searchSummary.classList.add("search-summary");
searchSummary.innerText = "";
const searchList = document.createElement("ul");
+ searchList.setAttribute("role", "list");
searchList.classList.add("search");
const out = document.getElementById("search-results");
@@ -318,7 +326,7 @@ const Search = {
const indexEntries = Search._index.indexentries;
// Collect multiple result groups to be sorted separately and then ordered.
// Each is an array of [docname, title, anchor, descr, score, filename].
const normalResults = [];
const nonMainIndexResults = [];
@@ -337,6 +345,7 @@ const Search = {
null,
score + boost,
filenames[file],
+ SearchResultKind.title,
]);
}
}
@@ -354,6 +363,7 @@ const Search = {
null,
score,
filenames[file],
+ SearchResultKind.index,
];
if (isMain) {
normalResults.push(result);
@@ -475,6 +485,7 @@ const Search = {
descr,
score,
filenames[match[0]],
+ SearchResultKind.object,
]);
};
Object.keys(objects).forEach((prefix) =>
@@ -585,6 +596,7 @@ const Search = {
null,
score,
filenames[file],
+ SearchResultKind.text,
]);
}
return results;
@@ -138,7 +145,7 @@ const _displayNextItem = (
};
// Helper function used by query() to order search results.
-// Each input is an array of [docname, title, anchor, descr, score, filename].
+// Each input is an array of [docname, title, anchor, descr, score, filename, kind].
// Order the results by score (in opposite order of appearance, since the
// `_displayNextItem` function uses pop() to retrieve items) and then alphabetically.
@@ -318,7 +326,7 @@ const Search = {
const indexEntries = Search._index.indexentries;
// Collect multiple result groups to be sorted separately and then ordered.
- // Each is an array of [docname, title, anchor, descr, score, filename].
+ // Each is an array of [docname, title, anchor, descr, score, filename, kind].
const normalResults = [];
const nonMainIndexResults = [];